# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.releases_api import ReleasesApi


class TestReleasesApi(unittest.TestCase):
    """ReleasesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReleasesApi()

    def tearDown(self) -> None:
        pass

    def test_create_component_release(self) -> None:
        """Test case for create_component_release

        create a release
        """
        pass

    def test_get_app_releases(self) -> None:
        """Test case for get_app_releases

        get all releases for an app
        """
        pass

    def test_get_component_releases(self) -> None:
        """Test case for get_component_releases

        get all releases for a component
        """
        pass

    def test_get_release(self) -> None:
        """Test case for get_release

        get a release
        """
        pass

    def test_get_release_steps(self) -> None:
        """Test case for get_release_steps

        get a release
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_component_config_connection import AppComponentConfigConnection

class TestAppComponentConfigConnection(unittest.TestCase):
    """AppComponentConfigConnection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppComponentConfigConnection:
        """Test AppComponentConfigConnection
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppComponentConfigConnection`
        """
        model = AppComponentConfigConnection()
        if include_optional:
            return AppComponentConfigConnection(
                component_id = '',
                created_at = '',
                created_by_id = '',
                docker_build = nuon.models.app/docker_build_component_config.app.DockerBuildComponentConfig(
                    build_args = [
                        ''
                        ], 
                    component_config_connection_id = '', 
                    connected_github_vcs_config = nuon.models.app/connected_github_vcs_config.app.ConnectedGithubVCSConfig(
                        branch = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        directory = '', 
                        id = '', 
                        repo = '', 
                        repo_name = '', 
                        repo_owner = '', 
                        updated_at = '', 
                        vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                            created_at = '', 
                            created_by_id = '', 
                            github_install_id = '', 
                            id = '', 
                            updated_at = '', 
                            vcs_connection_commit = [
                                nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                    author_email = '', 
                                    author_name = '', 
                                    component_config_connection_id = '', 
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    message = '', 
                                    sha = '', 
                                    updated_at = '', )
                                ], ), 
                        vcs_connection_id = '', ), 
                    created_at = '', 
                    created_by_id = '', 
                    dockerfile = '', 
                    env_vars = {
                        'key' : ''
                        }, 
                    id = '', 
                    public_git_vcs_config = nuon.models.app/public_git_vcs_config.app.PublicGitVCSConfig(
                        branch = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        directory = '', 
                        id = '', 
                        repo = '', 
                        updated_at = '', ), 
                    target = '', 
                    updated_at = '', ),
                external_image = nuon.models.app/external_image_component_config.app.ExternalImageComponentConfig(
                    aws_ecr_image_config = nuon.models.app/awsecr_image_config.app.AWSECRImageConfig(
                        aws_region = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        iam_role_arn = '', 
                        id = '', 
                        updated_at = '', ), 
                    component_config_connection_id = '', 
                    created_at = '', 
                    created_by_id = '', 
                    id = '', 
                    image_url = '', 
                    tag = '', 
                    updated_at = '', ),
                helm = nuon.models.app/helm_component_config.app.HelmComponentConfig(
                    chart_name = '', 
                    component_config_connection_id = '', 
                    connected_github_vcs_config = nuon.models.app/connected_github_vcs_config.app.ConnectedGithubVCSConfig(
                        branch = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        directory = '', 
                        id = '', 
                        repo = '', 
                        repo_name = '', 
                        repo_owner = '', 
                        updated_at = '', 
                        vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                            created_at = '', 
                            created_by_id = '', 
                            github_install_id = '', 
                            id = '', 
                            updated_at = '', 
                            vcs_connection_commit = [
                                nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                    author_email = '', 
                                    author_name = '', 
                                    component_config_connection_id = '', 
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    message = '', 
                                    sha = '', 
                                    updated_at = '', )
                                ], ), 
                        vcs_connection_id = '', ), 
                    created_at = '', 
                    created_by_id = '', 
                    id = '', 
                    public_git_vcs_config = nuon.models.app/public_git_vcs_config.app.PublicGitVCSConfig(
                        branch = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        directory = '', 
                        id = '', 
                        repo = '', 
                        updated_at = '', ), 
                    updated_at = '', 
                    values = {
                        'key' : ''
                        }, ),
                id = '',
                job = nuon.models.app/job_component_config.app.JobComponentConfig(
                    args = [
                        ''
                        ], 
                    cmd = [
                        ''
                        ], 
                    component_config_connection_id = '', 
                    created_at = '', 
                    created_by_id = '', 
                    env_vars = {
                        'key' : ''
                        }, 
                    id = '', 
                    image_url = '', 
                    tag = '', 
                    updated_at = '', ),
                terraform_module = nuon.models.app/terraform_module_component_config.app.TerraformModuleComponentConfig(
                    component_config_connection_id = '', 
                    connected_github_vcs_config = nuon.models.app/connected_github_vcs_config.app.ConnectedGithubVCSConfig(
                        branch = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        directory = '', 
                        id = '', 
                        repo = '', 
                        repo_name = '', 
                        repo_owner = '', 
                        updated_at = '', 
                        vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                            created_at = '', 
                            created_by_id = '', 
                            github_install_id = '', 
                            id = '', 
                            updated_at = '', 
                            vcs_connection_commit = [
                                nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                    author_email = '', 
                                    author_name = '', 
                                    component_config_connection_id = '', 
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    message = '', 
                                    sha = '', 
                                    updated_at = '', )
                                ], ), 
                        vcs_connection_id = '', ), 
                    created_at = '', 
                    created_by_id = '', 
                    env_vars = {
                        'key' : ''
                        }, 
                    id = '', 
                    public_git_vcs_config = nuon.models.app/public_git_vcs_config.app.PublicGitVCSConfig(
                        branch = '', 
                        component_config_id = '', 
                        component_config_type = '', 
                        created_at = '', 
                        created_by_id = '', 
                        directory = '', 
                        id = '', 
                        repo = '', 
                        updated_at = '', ), 
                    updated_at = '', 
                    variables = {
                        'key' : ''
                        }, 
                    version = '', ),
                updated_at = ''
            )
        else:
            return AppComponentConfigConnection(
        )
        """

    def testAppComponentConfigConnection(self):
        """Test AppComponentConfigConnection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.service_update_app_installer_request import ServiceUpdateAppInstallerRequest

class TestServiceUpdateAppInstallerRequest(unittest.TestCase):
    """ServiceUpdateAppInstallerRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceUpdateAppInstallerRequest:
        """Test ServiceUpdateAppInstallerRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceUpdateAppInstallerRequest`
        """
        model = ServiceUpdateAppInstallerRequest()
        if include_optional:
            return ServiceUpdateAppInstallerRequest(
                description = '',
                links = nuon.models.service_update_app_installer_request_links.service_UpdateAppInstallerRequest_links(
                    community = '', 
                    demo = '', 
                    documentation = '', 
                    github = '', 
                    homepage = '', 
                    logo = '', ),
                name = ''
            )
        else:
            return ServiceUpdateAppInstallerRequest(
                description = '',
                name = '',
        )
        """

    def testServiceUpdateAppInstallerRequest(self):
        """Test ServiceUpdateAppInstallerRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.statsd_event_alert_type import StatsdEventAlertType

class TestStatsdEventAlertType(unittest.TestCase):
    """StatsdEventAlertType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStatsdEventAlertType(self):
        """Test StatsdEventAlertType"""
        # inst = StatsdEventAlertType()

if __name__ == '__main__':
    unittest.main()
